@@ -216,6 +216,7 @@ def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
         return fn(*args, **kwargs)
 
     param = None
+    method = None
     if httpc_url.find('?') > -1:
         httpc_url, param = httpc_url.split('?')
 
@@ -235,9 +236,12 @@ def interceptor_httpc_request(fn, httpc_url, *args, **kwargs):
         UdpSession.send_packet(PacketTypeEnum.TX_HTTPC, ctx, datas)
 
         if conf.profile_http_parameter_enabled:
-            param = args[1].body or param
+            if type(args[1]) == dict:
+                param = (args[1].body if 'body' in args[1] else args[1]) or param
+                method = args[1].method if 'method' in args[1] else args[1]
+
             if param:
-                datas = ['HTTP-PARAMETERS', args[1].method, param]
+                datas = ['HTTP-PARAMETERS', method, param]
                 ctx.start_time = DateUtil.nowSystem()
                 UdpSession.send_packet(PacketTypeEnum.TX_SECURE_MSG, ctx, datas)
 
